pub struct AppQrMatchRules {
pub id: AppId,
pub rules_json: Vec<u8>,
}Fields
id: AppIdrules_json: Vec<u8>Trait Implementations
Sourceimpl Archive for AppQrMatchRules
impl Archive for AppQrMatchRules
Sourcetype Archived = ArchivedAppQrMatchRules
type Archived = ArchivedAppQrMatchRules
The archived representation of this type. Read more
Sourcetype Resolver = AppQrMatchRulesResolver
type Resolver = AppQrMatchRulesResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl Clone for AppQrMatchRules
impl Clone for AppQrMatchRules
Sourcefn clone(&self) -> AppQrMatchRules
fn clone(&self) -> AppQrMatchRules
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AppQrMatchRules
impl Debug for AppQrMatchRules
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AppQrMatchRules, __D> for Archived<AppQrMatchRules>
impl<__D: Fallible + ?Sized> Deserialize<AppQrMatchRules, __D> for Archived<AppQrMatchRules>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AppQrMatchRules, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AppQrMatchRules, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for AppQrMatchRules
impl<__S: Fallible + ?Sized> Serialize<__S> for AppQrMatchRules