pub struct GetAppIcon {
pub app_id: String,
}Expand description
Fetch the raw bytes of a single app’s bundled icon, keyed by its hex app id
(as returned in InstalledAppInfo::app_id). Returns None when the app
is unknown, has no bundled icon, or the icon cannot be read.
Fields
app_id: StringTrait Implementations
Sourceimpl Archive for GetAppIconwhere
String: Archive,
impl Archive for GetAppIconwhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetAppIcon
type Archived = ArchivedGetAppIcon
The archived representation of this type. Read more
Sourcetype Resolver = GetAppIconResolver
type Resolver = GetAppIconResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetAppIcon
impl BlockingArchive for GetAppIcon
Sourceimpl Clone for GetAppIcon
impl Clone for GetAppIcon
Sourcefn clone(&self) -> GetAppIcon
fn clone(&self) -> GetAppIcon
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAppIcon
impl Debug for GetAppIcon
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetAppIcon, __D> for Archived<GetAppIcon>
impl<__D: Fallible + ?Sized> Deserialize<GetAppIcon, __D> for Archived<GetAppIcon>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetAppIcon, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetAppIcon, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetAppIcon
impl MessageId for GetAppIcon
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for GetAppIconwhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for GetAppIconwhere
String: Serialize<__S>,