pub struct GetInstalledApps {
pub locale: String,
}Fields
locale: StringTrait Implementations
Sourceimpl Archive for GetInstalledAppswhere
String: Archive,
impl Archive for GetInstalledAppswhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetInstalledApps
type Archived = ArchivedGetInstalledApps
The archived representation of this type. Read more
Sourcetype Resolver = GetInstalledAppsResolver
type Resolver = GetInstalledAppsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetInstalledApps
impl BlockingArchive for GetInstalledApps
Sourcetype Response = Vec<InstalledAppInfo>
type Response = Vec<InstalledAppInfo>
response type for this message
Sourceimpl Clone for GetInstalledApps
impl Clone for GetInstalledApps
Sourcefn clone(&self) -> GetInstalledApps
fn clone(&self) -> GetInstalledApps
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetInstalledApps
impl Debug for GetInstalledApps
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetInstalledApps, __D> for Archived<GetInstalledApps>
impl<__D: Fallible + ?Sized> Deserialize<GetInstalledApps, __D> for Archived<GetInstalledApps>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetInstalledApps, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetInstalledApps, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetInstalledApps
impl MessageId for GetInstalledApps
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for GetInstalledAppswhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for GetInstalledAppswhere
String: Serialize<__S>,