pub struct GetPermissionRequestInfo {
pub sender_app_id: [u8; 16],
pub server_sid: [u32; 4],
pub message_id: usize,
pub locale: String,
}Fields
sender_app_id: [u8; 16]The requesting app’s id, captured by the kernel when the request was parked, so it is stable even if the sender exits and its pid is recycled before the broker asks.
server_sid: [u32; 4]The target server’s SID as captured by the kernel when the request was parked; it identifies the exact server even when one process hosts several.
message_id: usizelocale: StringTrait Implementations
Sourceimpl Archive for GetPermissionRequestInfo
impl Archive for GetPermissionRequestInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetPermissionRequestInfo
type Archived = ArchivedGetPermissionRequestInfo
The archived representation of this type. Read more
Sourcetype Resolver = GetPermissionRequestInfoResolver
type Resolver = GetPermissionRequestInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetPermissionRequestInfo
impl BlockingArchive for GetPermissionRequestInfo
Sourcetype Response = PermissionRequestInfoResult
type Response = PermissionRequestInfoResult
response type for this message
Sourceimpl Clone for GetPermissionRequestInfo
impl Clone for GetPermissionRequestInfo
Sourcefn clone(&self) -> GetPermissionRequestInfo
fn clone(&self) -> GetPermissionRequestInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetPermissionRequestInfo
impl Debug for GetPermissionRequestInfo
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetPermissionRequestInfo, __D> for Archived<GetPermissionRequestInfo>where
[u8; 16]: Archive,
<[u8; 16] as Archive>::Archived: Deserialize<[u8; 16], __D>,
[u32; 4]: Archive,
<[u32; 4] as Archive>::Archived: Deserialize<[u32; 4], __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
impl<__D: Fallible + ?Sized> Deserialize<GetPermissionRequestInfo, __D> for Archived<GetPermissionRequestInfo>where
[u8; 16]: Archive,
<[u8; 16] as Archive>::Archived: Deserialize<[u8; 16], __D>,
[u32; 4]: Archive,
<[u32; 4] as Archive>::Archived: Deserialize<[u32; 4], __D>,
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetPermissionRequestInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetPermissionRequestInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetPermissionRequestInfo
impl MessageId for GetPermissionRequestInfo
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for GetPermissionRequestInfo
impl<__S: Fallible + ?Sized> Serialize<__S> for GetPermissionRequestInfo