pub struct GetQrMatchRules;Trait Implementations
Sourceimpl Archive for GetQrMatchRules
impl Archive for GetQrMatchRules
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedGetQrMatchRules
type Archived = ArchivedGetQrMatchRules
The archived representation of this type. Read more
Sourcetype Resolver = GetQrMatchRulesResolver
type Resolver = GetQrMatchRulesResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for GetQrMatchRules
impl BlockingArchive for GetQrMatchRules
Sourcetype Response = Vec<AppQrMatchRules>
type Response = Vec<AppQrMatchRules>
response type for this message
Sourceimpl Clone for GetQrMatchRules
impl Clone for GetQrMatchRules
Sourcefn clone(&self) -> GetQrMatchRules
fn clone(&self) -> GetQrMatchRules
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetQrMatchRules
impl Debug for GetQrMatchRules
Sourceimpl<__D: Fallible + ?Sized> Deserialize<GetQrMatchRules, __D> for Archived<GetQrMatchRules>
impl<__D: Fallible + ?Sized> Deserialize<GetQrMatchRules, __D> for Archived<GetQrMatchRules>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<GetQrMatchRules, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<GetQrMatchRules, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for GetQrMatchRules
impl MessageId for GetQrMatchRules