pub struct InstallAppArchiveResult {
pub app_name: String,
}Fields
app_name: StringTrait Implementations
Sourceimpl Archive for InstallAppArchiveResultwhere
String: Archive,
impl Archive for InstallAppArchiveResultwhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedInstallAppArchiveResult
type Archived = ArchivedInstallAppArchiveResult
The archived representation of this type. Read more
Sourcetype Resolver = InstallAppArchiveResultResolver
type Resolver = InstallAppArchiveResultResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for InstallAppArchiveResult
impl Clone for InstallAppArchiveResult
Sourcefn clone(&self) -> InstallAppArchiveResult
fn clone(&self) -> InstallAppArchiveResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstallAppArchiveResult
impl Debug for InstallAppArchiveResult
Sourceimpl<__D: Fallible + ?Sized> Deserialize<InstallAppArchiveResult, __D> for Archived<InstallAppArchiveResult>
impl<__D: Fallible + ?Sized> Deserialize<InstallAppArchiveResult, __D> for Archived<InstallAppArchiveResult>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<InstallAppArchiveResult, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<InstallAppArchiveResult, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for InstallAppArchiveResult
impl PartialEq for InstallAppArchiveResult
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for InstallAppArchiveResultwhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for InstallAppArchiveResultwhere
String: Serialize<__S>,
impl Eq for InstallAppArchiveResult
impl StructuralPartialEq for InstallAppArchiveResult