pub struct InstalledAppInfo {
pub app_id: String,
pub name: String,
pub bundled_icon_path: Option<String>,
pub publisher: String,
pub can_launch: bool,
pub can_remove: bool,
pub version: String,
pub size_bytes: u64,
pub description: String,
pub permissions: Vec<InstalledAppPermissionGroup>,
}Fields
app_id: Stringname: Stringbundled_icon_path: Option<String>On-disk path/reference for the app’s bundled icon when it exists. Icon
bytes are fetched separately via GetAppIcon on device so a single
large icon (or many apps) cannot overflow the listing’s IPC buffer.
publisher: Stringcan_launch: boolcan_remove: boolversion: Stringsize_bytes: u64description: Stringpermissions: Vec<InstalledAppPermissionGroup>Trait Implementations
Sourceimpl Archive for InstalledAppInfo
impl Archive for InstalledAppInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedInstalledAppInfo
type Archived = ArchivedInstalledAppInfo
The archived representation of this type. Read more
Sourcetype Resolver = InstalledAppInfoResolver
type Resolver = InstalledAppInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for InstalledAppInfo
impl Clone for InstalledAppInfo
Sourcefn clone(&self) -> InstalledAppInfo
fn clone(&self) -> InstalledAppInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstalledAppInfo
impl Debug for InstalledAppInfo
Sourceimpl<__D: Fallible + ?Sized> Deserialize<InstalledAppInfo, __D> for Archived<InstalledAppInfo>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<InstalledAppPermissionGroup>: Archive,
<Vec<InstalledAppPermissionGroup> as Archive>::Archived: Deserialize<Vec<InstalledAppPermissionGroup>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<InstalledAppInfo, __D> for Archived<InstalledAppInfo>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Vec<InstalledAppPermissionGroup>: Archive,
<Vec<InstalledAppPermissionGroup> as Archive>::Archived: Deserialize<Vec<InstalledAppPermissionGroup>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<InstalledAppInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<InstalledAppInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for InstalledAppInfo
impl<__S: Fallible + ?Sized> Serialize<__S> for InstalledAppInfo