pub struct InstalledAppPermissionSubgroup {
pub key: String,
pub label: String,
pub approved: bool,
}Expand description
One permission subgroup of an app, the unit the user sees, approves, and denies. The individual messages behind it stay internal to the OS.
Fields
key: Stringlabel: Stringapproved: boolTrait Implementations
Sourceimpl Archive for InstalledAppPermissionSubgroup
impl Archive for InstalledAppPermissionSubgroup
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedInstalledAppPermissionSubgroup
type Archived = ArchivedInstalledAppPermissionSubgroup
The archived representation of this type. Read more
Sourcetype Resolver = InstalledAppPermissionSubgroupResolver
type Resolver = InstalledAppPermissionSubgroupResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for InstalledAppPermissionSubgroup
impl Clone for InstalledAppPermissionSubgroup
Sourcefn clone(&self) -> InstalledAppPermissionSubgroup
fn clone(&self) -> InstalledAppPermissionSubgroup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<__D: Fallible + ?Sized> Deserialize<InstalledAppPermissionSubgroup, __D> for Archived<InstalledAppPermissionSubgroup>
impl<__D: Fallible + ?Sized> Deserialize<InstalledAppPermissionSubgroup, __D> for Archived<InstalledAppPermissionSubgroup>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<InstalledAppPermissionSubgroup, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<InstalledAppPermissionSubgroup, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for InstalledAppPermissionSubgroup
impl<__S: Fallible + ?Sized> Serialize<__S> for InstalledAppPermissionSubgroup