pub struct ListApps {
pub locale: String,
pub filter: AppFilter,
}Fields
locale: Stringfilter: AppFilterTrait Implementations
Sourceimpl Archive for ListApps
impl Archive for ListApps
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedListApps
type Archived = ArchivedListApps
The archived representation of this type. Read more
Sourcetype Resolver = ListAppsResolver
type Resolver = ListAppsResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for ListApps
impl BlockingArchive for ListApps