pub struct RefreshInstalledApp(pub AppId);Expand description
Rescan the app set after a completed in-place replacement. The supplied app is reported as installed even when its manifest is unchanged, so subscribers also refresh resources such as icons that are not part of the manifest.
Tuple Fields
0: AppIdTrait Implementations
Sourceimpl BlockingScalar for RefreshInstalledApp
impl BlockingScalar for RefreshInstalledApp
Sourcetype Response = Result<(), AppManagerError>
type Response = Result<(), AppManagerError>
response type for this message
Sourceimpl Debug for RefreshInstalledApp
impl Debug for RefreshInstalledApp
Sourceimpl FromScalar<4> for RefreshInstalledApp
impl FromScalar<4> for RefreshInstalledApp
fn from_scalar(value: [u32; 4]) -> Self