pub struct RemoveInstalledApp {
pub app_id: AppId,
}Fields
app_id: AppIdTrait Implementations
Sourceimpl Archive for RemoveInstalledAppwhere
WithAppId: ArchiveWith<AppId>,
impl Archive for RemoveInstalledAppwhere
WithAppId: ArchiveWith<AppId>,
Sourcetype Archived = ArchivedRemoveInstalledApp
type Archived = ArchivedRemoveInstalledApp
The archived representation of this type. Read more
Sourcetype Resolver = RemoveInstalledAppResolver
type Resolver = RemoveInstalledAppResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourcefn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
fn resolve(&self, resolver: Self::Resolver, out: Place<Self::Archived>)
Creates the archived version of this value at the given position and
writes it to the given output. Read more
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
const COPY_OPTIMIZATION: CopyOptimization<Self> = _
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourceimpl BlockingArchive for RemoveInstalledApp
impl BlockingArchive for RemoveInstalledApp
Sourcetype Response = RemoveInstalledAppResult
type Response = RemoveInstalledAppResult
response type for this message
Sourceimpl Clone for RemoveInstalledApp
impl Clone for RemoveInstalledApp
Sourcefn clone(&self) -> RemoveInstalledApp
fn clone(&self) -> RemoveInstalledApp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoveInstalledApp
impl Debug for RemoveInstalledApp
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RemoveInstalledApp, __D> for Archived<RemoveInstalledApp>
impl<__D: Fallible + ?Sized> Deserialize<RemoveInstalledApp, __D> for Archived<RemoveInstalledApp>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RemoveInstalledApp, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RemoveInstalledApp, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for RemoveInstalledApp
impl MessageId for RemoveInstalledApp
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RemoveInstalledAppwhere
WithAppId: SerializeWith<AppId, __S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RemoveInstalledAppwhere
WithAppId: SerializeWith<AppId, __S>,