pub struct RemoveThirdPartyCertificate {
pub public_key: String,
pub locale: String,
}Fields
public_key: Stringlocale: StringTrait Implementations
Sourceimpl Archive for RemoveThirdPartyCertificatewhere
String: Archive,
impl Archive for RemoveThirdPartyCertificatewhere
String: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRemoveThirdPartyCertificate
type Archived = ArchivedRemoveThirdPartyCertificate
The archived representation of this type. Read more
Sourcetype Resolver = RemoveThirdPartyCertificateResolver
type Resolver = RemoveThirdPartyCertificateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for RemoveThirdPartyCertificate
impl BlockingArchive for RemoveThirdPartyCertificate
Sourcetype Response = RemoveThirdPartyCertificateResult
type Response = RemoveThirdPartyCertificateResult
response type for this message
Sourceimpl Clone for RemoveThirdPartyCertificate
impl Clone for RemoveThirdPartyCertificate
Sourcefn clone(&self) -> RemoveThirdPartyCertificate
fn clone(&self) -> RemoveThirdPartyCertificate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoveThirdPartyCertificate
impl Debug for RemoveThirdPartyCertificate
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RemoveThirdPartyCertificate, __D> for Archived<RemoveThirdPartyCertificate>
impl<__D: Fallible + ?Sized> Deserialize<RemoveThirdPartyCertificate, __D> for Archived<RemoveThirdPartyCertificate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RemoveThirdPartyCertificate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RemoveThirdPartyCertificate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RemoveThirdPartyCertificatewhere
String: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RemoveThirdPartyCertificatewhere
String: Serialize<__S>,