pub struct SetAppPermissionGrant {
pub app_id: String,
pub subgroup: String,
pub decision: PermissionGrantDecision,
}Fields
app_id: Stringsubgroup: StringSubgroup key (e.g. peripherals.camera-use); the grant covers every message in it.
decision: PermissionGrantDecisionTrait Implementations
Sourceimpl Archive for SetAppPermissionGrantwhere
String: Archive,
PermissionGrantDecision: Archive,
impl Archive for SetAppPermissionGrantwhere
String: Archive,
PermissionGrantDecision: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetAppPermissionGrant
type Archived = ArchivedSetAppPermissionGrant
The archived representation of this type. Read more
Sourcetype Resolver = SetAppPermissionGrantResolver
type Resolver = SetAppPermissionGrantResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for SetAppPermissionGrant
impl BlockingArchive for SetAppPermissionGrant
Sourcetype Response = SetAppPermissionGrantResult
type Response = SetAppPermissionGrantResult
response type for this message
Sourceimpl Clone for SetAppPermissionGrant
impl Clone for SetAppPermissionGrant
Sourcefn clone(&self) -> SetAppPermissionGrant
fn clone(&self) -> SetAppPermissionGrant
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetAppPermissionGrant
impl Debug for SetAppPermissionGrant
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetAppPermissionGrant, __D> for Archived<SetAppPermissionGrant>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
PermissionGrantDecision: Archive,
<PermissionGrantDecision as Archive>::Archived: Deserialize<PermissionGrantDecision, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SetAppPermissionGrant, __D> for Archived<SetAppPermissionGrant>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
PermissionGrantDecision: Archive,
<PermissionGrantDecision as Archive>::Archived: Deserialize<PermissionGrantDecision, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetAppPermissionGrant, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetAppPermissionGrant, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for SetAppPermissionGrant
impl MessageId for SetAppPermissionGrant
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SetAppPermissionGrantwhere
String: Serialize<__S>,
PermissionGrantDecision: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for SetAppPermissionGrantwhere
String: Serialize<__S>,
PermissionGrantDecision: Serialize<__S>,