pub struct ThirdPartyCertificateInfo {Show 13 fields
pub name: String,
pub company: String,
pub contact_email: String,
pub support_url: String,
pub public_key: String,
pub not_before_unix_seconds: Option<u64>,
pub not_after_unix_seconds: Option<u64>,
pub serial_number: String,
pub issuer: String,
pub subject: String,
pub basic_constraints: String,
pub key_usage: String,
pub extended_key_usage: String,
}Fields
name: Stringcompany: Stringcontact_email: Stringsupport_url: Stringpublic_key: Stringnot_before_unix_seconds: Option<u64>not_after_unix_seconds: Option<u64>serial_number: Stringissuer: Stringsubject: Stringbasic_constraints: Stringkey_usage: Stringextended_key_usage: StringTrait Implementations
Sourceimpl Archive for ThirdPartyCertificateInfo
impl Archive for ThirdPartyCertificateInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedThirdPartyCertificateInfo
type Archived = ArchivedThirdPartyCertificateInfo
The archived representation of this type. Read more
Sourcetype Resolver = ThirdPartyCertificateInfoResolver
type Resolver = ThirdPartyCertificateInfoResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for ThirdPartyCertificateInfo
impl Clone for ThirdPartyCertificateInfo
Sourcefn clone(&self) -> ThirdPartyCertificateInfo
fn clone(&self) -> ThirdPartyCertificateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThirdPartyCertificateInfo
impl Debug for ThirdPartyCertificateInfo
Sourceimpl<'de> Deserialize<'de> for ThirdPartyCertificateInfo
impl<'de> Deserialize<'de> for ThirdPartyCertificateInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ThirdPartyCertificateInfo, __D> for Archived<ThirdPartyCertificateInfo>
impl<__D: Fallible + ?Sized> Deserialize<ThirdPartyCertificateInfo, __D> for Archived<ThirdPartyCertificateInfo>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<ThirdPartyCertificateInfo, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<ThirdPartyCertificateInfo, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for ThirdPartyCertificateInfo
impl<__S: Fallible + ?Sized> Serialize<__S> for ThirdPartyCertificateInfo