pub struct PreviewThirdPartyCertificate {
pub certificate_pem: Vec<u8>,
}Fields
certificate_pem: Vec<u8>Trait Implementations
Sourceimpl Archive for PreviewThirdPartyCertificate
impl Archive for PreviewThirdPartyCertificate
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPreviewThirdPartyCertificate
type Archived = ArchivedPreviewThirdPartyCertificate
The archived representation of this type. Read more
Sourcetype Resolver = PreviewThirdPartyCertificateResolver
type Resolver = PreviewThirdPartyCertificateResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for PreviewThirdPartyCertificate
impl BlockingArchive for PreviewThirdPartyCertificate
Sourcetype Response = Result<ThirdPartyCertificateInfo, ThirdPartyCertificateError>
type Response = Result<ThirdPartyCertificateInfo, ThirdPartyCertificateError>
response type for this message
Sourceimpl Clone for PreviewThirdPartyCertificate
impl Clone for PreviewThirdPartyCertificate
Sourcefn clone(&self) -> PreviewThirdPartyCertificate
fn clone(&self) -> PreviewThirdPartyCertificate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PreviewThirdPartyCertificate
impl Debug for PreviewThirdPartyCertificate
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PreviewThirdPartyCertificate, __D> for Archived<PreviewThirdPartyCertificate>
impl<__D: Fallible + ?Sized> Deserialize<PreviewThirdPartyCertificate, __D> for Archived<PreviewThirdPartyCertificate>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PreviewThirdPartyCertificate, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PreviewThirdPartyCertificate, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for PreviewThirdPartyCertificate
impl<__S: Fallible + ?Sized> Serialize<__S> for PreviewThirdPartyCertificate