KeyOS API Reference

RefreshInstalledApp

Struct RefreshInstalledApp 

pub struct RefreshInstalledApp(pub AppId);
Rescan the app set after a completed in-place replacement. The supplied app is reported as installed even when its manifest is unchanged, so subscribers also refresh resources such as icons that are not part of the manifest.

Tuple Fields

0: AppId